<!-- Feel free to remove check-list items aren't relevant to your changes -->

 - [ ] Closes #xxxx
 - [ ] Tests added and `nox` passes.
 - [ ] Passes `pre-commit run --all-files`
 - [ ] Changes and the contributor name are documented in `HISTORY.rst`.
